<?php

/**
 * Admin API: Core AJAX handlers.
 *
 * @since 1.0
 * @package Core AJAX handlers
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_action( 'wp_ajax_nopriv_get_tax_list', 'get_tax_list_handler' );
add_action( 'wp_ajax_get_tax_list', 'get_tax_list_handler' );

/**
 * Get taxonomies list.
 *
 * @since 1.0.0
 */
function get_tax_list_handler() {
	header( 'Content-Type: application/json' );
	$response = array();
	$cat_html = '';
	$tag_html = '';

	$cbdb_post_type = isset( $_POST['post_type'] ) ? sanitize_text_field( wp_unslash( $_POST['post_type'] ) ) : '';

	if ( ! empty( $cbdb_post_type ) ) {
		// Get a list of available taxonomies for a post type.
		$taxonomies = get_taxonomies( array( 'object_type' => array( $cbdb_post_type ) ) );

		// Set category and tag index.
		$cat_index = 1;
		$tag_index = 2;
		if ( $cbdb_post_type == 'product' ) {
			$cat_index = 2;
			$tag_index = 3;
		}

		$outer_cnt = 1;
		// Loop over your taxonomies.
		foreach ( $taxonomies as $taxonomy ) {
			// Retrieve all available terms, including those not yet used.
			$terms = get_terms(
				array(
					'taxonomy'   => $taxonomy,
					'hide_empty' => false,
				)
			);

			$inner_cnt = 1;
			foreach ( $terms as $term ) {
				// For category.
				if ( $outer_cnt == $cat_index ) {
					$cat_html .= '<option value="' . $term->slug . '">' . esc_html( $term->name ) . '</option>';
					$inner_cnt++;
				}
				// For tag.
				if ( $outer_cnt == $tag_index ) {
					$tag_html .= '<option value="' . $term->slug . '">' . esc_html( $term->name ) . '</option>';
					$inner_cnt++;
				}
			}
			$outer_cnt++;
		}
	}

	$response['catHTML'] = $cat_html;
	$response['tagHTML'] = $tag_html;

	echo wp_json_encode( $response );
	wp_die();
}

add_action( 'wp_ajax_nopriv_get_layout_list', 'get_layout_list_handler' );
add_action( 'wp_ajax_get_layout_list', 'get_layout_list_handler' );

/**
 * Get layouts list.
 *
 * @since 1.0.0
 */
function get_layout_list_handler() {
	header( 'Content-Type: application/json' );
	$response     = array();
	$options_html = '';

	$cbdb_layout_type = isset( $_POST['layout_type'] ) ? sanitize_text_field( wp_unslash( $_POST['layout_type'] ) ) : '';

	if ( $cbdb_layout_type ) {
		$layout_options_arr = CBDB_Utility::layout_preview_options( $cbdb_layout_type );
		if ( ! empty( $layout_options_arr ) ) {
			foreach ( $layout_options_arr as $layout_option ) {
				$options_html .= '<option class="cbdb-option" value="' . esc_attr( $layout_option ) . '">' . esc_html( ucfirst( str_replace( '-', ' ', $layout_option ) ) ) . '</option>';
			}
		}
	}

	$response['optionsHTML'] = $options_html;

	echo wp_json_encode( $response );
	wp_die();
}
