jQuery(document).ready(function () {
    
    "use strict";
    
    // Set up some blank variable
    var page, cbdbID, masonryOptions, masonry, masonryGutter, masonryWidth = '';

    // Pagination click event
    if (jQuery('.cbdb-pagination a').length) {
        jQuery('.cbdb-pagination-wrapper').on('click', '.cbdb-pagination a', function (e) {
            e.preventDefault();
            page = jQuery(this).html();
            if (jQuery(this).hasClass('prev')) {
                page = jQuery(this).parent().find('span.current').html();
                page = parseInt(page) - 1;
            } else if (jQuery(this).hasClass('next')) {
                page = jQuery(this).parent().find('span.current').html();
                page = parseInt(page) + 1;
            }
            cbdbID = jQuery(this).parent().attr('data-sc-id');
            cbdb_get_posts(cbdbID);
        });
    }

    // If masonry layout exists
    // We have used isotope library for masonry layout
    if (jQuery('.cbdb-masonry-layout').length) {
        jQuery('.cbdb-main-section').each(function () {
            cbdbID = jQuery(this).attr('data-cbdb-sc-id');
            masonryGutter = cbdb_get_masonry_gutter(cbdbID);
            masonryOptions = {
                itemSelector: '.cbdb-masonry-item',
                layoutMode: 'masonry',
                containerStyle: {
                    position: 'relative',
                    overflow: 'visible'
                },
                masonry: {
                    columnWidth: Number(masonryGutter.cbdb_grid_gap),
                    rowHeight: Number(masonryGutter.cbdb_row_gap)
                }
            };
            // Init isotope
            masonry = jQuery('.cbdb-sc-' + cbdbID).isotope(masonryOptions);
        });
    }

    // Pagination function
    function cbdb_get_posts(cbdbID) {
        var resArr = [];
        if (cbdbID) {
            jQuery.ajax({
                type: 'POST',
                url: cbdb_front_ajax_object.ajaxurl,
                data: {
                    nonce_ajax: cbdb_front_ajax_object.nonce,
                    page_number: page,
                    cbdb_id: cbdbID,
                    action: 'cbdb_get_pagination_posts',
                },
                dataType: 'html',
                success: function (response) {
                    if (response != '') {
                        // Empty old previous page posts and add next page posts
                        resArr = response.split('<nav ');
                        jQuery('.cbdb-sc-' + cbdbID).html('').html(resArr[0]);
                        // If masonry layout
                        if (jQuery('.cbdb-masonry-layout').length) {
                            jQuery('.cbdb-sc-' + cbdbID).isotope('destroy'); // destroy
                            masonryGutter = cbdb_get_masonry_gutter(cbdbID);
                            masonryOptions = {
                                itemSelector: '.cbdb-masonry-item',
                                layoutMode: 'masonry',
                                containerStyle: {
                                    position: 'relative',
                                    overflow: 'visible'
                                },
                                masonry: {
                                    columnWidth: Number(masonryGutter.cbdb_grid_gap),
                                    rowHeight: Number(masonryGutter.cbdb_row_gap)
                                }
                            };
                            jQuery('.cbdb-sc-' + cbdbID).isotope(masonryOptions); // re-initialize
                        }
                        jQuery('#cbdb-pagination-wrapper-' + cbdbID).html('').html('<nav ' + resArr[1]);

                        jQuery('html, body').animate({
                            scrollTop: jQuery('.cbdb-sc-' + cbdbID).offset().top - 100
                        }, 500);
                    }
                },
                error: function (jqXHR, exception) {
                    console.log(jqXHR.status);
                    console.log(jqXHR.statusCode);
                    console.log(exception);
                }
            });
        }
    }

    // Masonry gutter function
    function cbdb_get_masonry_gutter(cbdbID) {
        masonryWidth = '';
        if (cbdbID) {
            jQuery.ajax({
                type: 'POST',
                url: cbdb_front_ajax_object.ajaxurl,
                data: {
                    cbdb_id: cbdbID,
                    action: 'cbdb_get_masonry_gutter'
                },
                dataType: 'json',
                async: false
            }).done(function (data) {
                masonryWidth = data;
            }).fail(function (jqXHR, textStatus, errorThrown) {
                masonryWidth = '';
            });
        }
        return masonryWidth;
    }
});