<?php

/**
 * Add support to WPBakery Page Builder plugin
 *
 * @since 1.0
 * @package CBDB_Builder_Functions
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if directly access.
}

/**
 * Function that returns post widget
 *
 * @since 1.0
 */
class CBDB_Builder_Functions {

	/**
	 * WPBakery builder class constructor.
	 *
	 * @since 1.0
	 */
	public function __construct() {
		add_action( 'vc_before_init', array( $this, 'cbdb_add_vc_support' ) );
	}

	/**
	 * Add WPBakery (Visual Composer) support.
	 *
	 * @since 1.0
	 */
	public function cbdb_add_vc_support() {
		global $wpdb;
		$cbdb_table_name = $wpdb->prefix . 'creative_blog_shortcodes';
        $cbdb_ids = $wpdb->get_results( "SELECT cbdb_id,cbdb_sc_name FROM $cbdb_table_name" ); //phpcs:ignore
		$cbdb_ids_array  = array( 'Select Layout', 'creative-blog' );
		if ( ! empty( $cbdb_ids ) && is_array( $cbdb_ids ) ) {
			foreach ( $cbdb_ids as $cbdb_layout_id ) {
				$cbdb_layout_array[ $cbdb_layout_id->cbdb_sc_name ] = $cbdb_layout_id->cbdb_id;
			}
		}
		vc_map(
			array(
				'name'              => esc_html__( 'Creative Blog', 'creative-blog' ),
				'base'              => 'creative_blog',
				'class'             => 'creative_blog_section',
				'category'          => esc_html__( 'Content', 'creative-blog' ),
				'icon'              => 'creative_blog_icon',
				'admin_enqueue_css' => array( CBDB_URL . 'admin/assets/css/vc-style.css' ),
				'description'       => esc_html__( 'Custom Blog Layouts', 'creative-blog' ),
				'params'            => array(
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Select Creative Blog Layout', 'creative-blog' ),
						'param_name'  => 'id',
						'value'       => $cbdb_layout_array,
						'admin_label' => true,
					),
				),
			)
		);
	}

}

new CBDB_Builder_Functions();
