<?php
/**
 * Display shortcode
 *
 * @since 1.0
 * @package add_shortcode
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Function that runs when shortcode is called.
 *
 * @param type $atts     Shortcode attributes.
 * @param type $content Shortcode content.
 * @return type string Shortcode HTML.
 *
 * @since 1.0
 */
function creative_blog_handler( $atts, $content = null ) {
	// Define global DB object.
	global $wpdb;

	// Define DB table name.
	$cbdb_dbtable = $wpdb->prefix . 'creative_blog_shortcodes';

	// Default parameters.
	extract(
		shortcode_atts(
			array(
				'id' => '',
			),
			$atts
		)
	);

	// Get shortcode id.
	$cbdb_id = $id;

	// Fire a database query.
	$cbdb_rowdata = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$cbdb_dbtable} WHERE cbdb_id = %d LIMIT %d", array( $cbdb_id, 1 ) ), 'ARRAY_A' );

	// Start output buffer.
	ob_start();

	// Check if data is empty.
	if ( ! empty( $cbdb_rowdata ) ) {
		// Get all settings.
		$cbdb_settings = unserialize( $cbdb_rowdata['cbdb_settings'] );

		// Frontend common data file.
		include CBDB_DIR . 'inc/cbdb-front-common-data.php';

		// Enqueue relevant layout CSS file.
		wp_enqueue_style( "cbdb-{$cbdb_layout_type}-layout-style" );

		// Viewport columns for grid layout only.
		if ( $cbdb_layout_type == 'grid' ) {
			$http_user_agent = isset( $_SERVER['HTTP_USER_AGENT'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_USER_AGENT'] ) ) : '';
			if ( str_contains( $http_user_agent, 'iPhone' ) ) {
				// Class for mobile.
				for ( $i = 1; $i <= 6; $i++ ) {
					if ( $cbdb_mobile_col == $i ) {
						$cbdb_grid_column = "cbdb-grid-col-{$i}";
					}
				}
			} elseif ( str_contains( $http_user_agent, 'iPad' ) ) {
				// Class for iPad/tablet.
				for ( $i = 1; $i <= 6; $i++ ) {
					if ( $cbdb_ipad_tab_col == $i ) {
						$cbdb_grid_column = "cbdb-grid-col-{$i}";
					}
				}
			} else {
				// Class for desktop.
				for ( $i = 1; $i <= 6; $i++ ) {
					if ( $cbdb_desktop_col == $i ) {
						$cbdb_grid_column = "cbdb-grid-col-{$i}";
					}
				}
			}
		}

		// Prepare arguments.
		$args = array(
			'post_type'      => $cbdb_post_type,
			'posts_per_page' => $cbdb_number_post,
			'post_status'    => 'publish',
			'orderby'        => $cbdb_settings['cbdb_order_by'],
			'order'          => $cbdb_settings['cbdb_order'],
		);

		// Exclude IN or NOT IN.
		$cbdb_post_cats = 'IN';
		if ( isset( $cbdb_settings['cbdb_exclude_categories'] ) && ! empty( $cbdb_settings['cbdb_exclude_categories'] ) ) {
			$cbdb_post_cats = 'NOT IN';
		}
		$cbdb_post_tags = 'IN';
		if ( isset( $cbdb_settings['cbdb_exclude_tags'] ) && ! empty( $cbdb_settings['cbdb_exclude_tags'] ) ) {
			$cbdb_post_tags = 'NOT IN';
		}
		$cbdb_authors = 'author__in';
		if ( isset( $cbdb_settings['cbdb_exclude_authors'] ) && ! empty( $cbdb_settings['cbdb_exclude_authors'] ) ) {
			$cbdb_authors = 'author__not_in';
		}

		// Get taxonomies name based on post type.
		$cbdb_post_taxonomies = get_object_taxonomies( $cbdb_post_type );
		// Query check all display category, tags and author.
		if ( ( isset( $cbdb_settings['cbdb_post_categories'] ) && ! empty( $cbdb_settings['cbdb_post_categories'] ) ) || ( isset( $cbdb_settings['cbdb_post_tags'] ) && ! empty( $cbdb_settings['cbdb_post_tags'] ) ) ) {
			$cbdb_cat_arr      = array();
			$cbdb_tag_arr      = array();
			$args['tax_query'] = array(
				'relation' => 'AND',
			);
			if ( ( isset( $cbdb_settings['cbdb_post_categories'] ) && ! empty( $cbdb_settings['cbdb_post_categories'] ) ) ) {
				$cbdb_cat_arr = array(
					'taxonomy' => $cbdb_post_taxonomies[0],
					'field'    => 'slug',
					'terms'    => $cbdb_settings['cbdb_post_categories'],
					'operator' => $cbdb_post_cats,
				);
				array_push( $args['tax_query'], $cbdb_cat_arr );
			}
			if ( ( isset( $cbdb_settings['cbdb_post_tags'] ) && ! empty( $cbdb_settings['cbdb_post_tags'] ) ) ) {
				$cbdb_tag_arr = array(
					'taxonomy' => $cbdb_post_taxonomies[1],
					'field'    => 'slug',
					'terms'    => $cbdb_settings['cbdb_post_tags'],
					'operator' => $cbdb_post_tags,
				);
				array_push( $args['tax_query'], $cbdb_tag_arr );
			}
		}
		if ( ( isset( $cbdb_settings['cbdb_post_authors'] ) && ! empty( $cbdb_settings['cbdb_post_authors'] ) ) ) {
			$args[ $cbdb_authors ] = $cbdb_settings['cbdb_post_authors'];
		}

		// Fire a database query.
		$get_posts = new WP_Query( $args );

		// Check if posts exists.
		if ( $get_posts->have_posts() ) {
			// Shortcode id class.
			$cbdb_id_class = 'cbdb-sc-' . $cbdb_id;

			// Section class.
			$section_class = 'cbdb-main-section-' . $cbdb_id_class;

			// Layout class.
			$layout_class = 'cbdb-' . $cbdb_layout_type . '-' . $cbdb_layout_preview;

			// Shortcode and layout combined class.
			$cbdb_combine = '.' . $section_class . ' .' . $cbdb_id_class . '.' . $layout_class;

			// Layout and column classes.
			$cbdb_custom_class = ' ' . $cbdb_id_class . ' cbdb-' . $cbdb_layout_type . '-' . $cbdb_layout_preview;

			// If layout is grid add grid column class.
			if ( $cbdb_layout_type == 'grid' ) {
				$cbdb_custom_class .= ' cbdb-grid-layout ' . $cbdb_grid_column;
			}
			if ( $cbdb_layout_type == 'masonry' ) {
				$cbdb_custom_class .= ' cbdb-masonry-layout';
				// Enqueue isotope library for masonry layout.
				wp_enqueue_script( 'isotope' );
			}
			wp_enqueue_script( 'cbdb-frontend-script' );

			// Include common CSS file.
			include 'cbdb-common-style.php';
			?>
			<section class="cbdb-main-section <?php echo esc_attr( $section_class ); ?>" data-cbdb-sc-id="<?php echo esc_attr( $cbdb_id ); ?>">
				<div class="cbdb-main-container <?php echo esc_attr( $cbdb_main_container_class_name . $cbdb_custom_class ); ?>">
					<?php
					// Loop through all posts.
					while ( $get_posts->have_posts() ) {
						$get_posts->the_post();
						$cbdb_post_id = get_the_ID();
						$cbdb_content = get_the_content();

						// Get selected layout type and check if the template file exists.
						$cbdb_template_file = CBDB_DIR . "templates/{$cbdb_layout_type}/{$cbdb_layout_type}-{$cbdb_layout_preview}.php";
						if ( file_exists( $cbdb_template_file ) ) {
							// If the template file exists include it.
							include $cbdb_template_file;
						} else {
							// Else no template file found.
							/* translators: 1: layout type, 2: layout preview */
							echo '<p>' . esc_html__( 'Sorry, this template does not exist, please choose another template', 'creative-blog' ) . '</p>';
							exit();
						}
					}
					// Reset post data.
					wp_reset_postdata();
					?>
				</div>
				<?php
				// If pagination is enabled.
				if ( file_exists( $cbdb_template_file ) && isset( $cbdb_settings['cbdb_post_pagination'] ) && $cbdb_settings['cbdb_post_pagination'] ) {
					?>
					<div class="cbdb-pagination-wrapper" id="cbdb-pagination-wrapper-<?php echo esc_attr( $cbdb_id ); ?>">
						<nav class="cbdb-pagination <?php echo esc_attr( $cbdb_settings['cbdb_pagination_preview'] ); ?>" id="cbdb_pagination" data-sc-id="<?php echo esc_attr( $cbdb_id ); ?>">
							<?php
							$big                 = 999999999; // Need an unlikely integer.
							$cbdb_paginate_links = array(
								'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
								'format'    => '?paged=%#%',
								'current'   => max( 1, get_query_var( 'paged' ) ),
								'total'     => $get_posts->max_num_pages,
								'prev_text' => esc_html__( 'Previous', 'creative-blog' ),
								'next_text' => esc_html__( 'Next', 'creative-blog' ),
							);
							if ( isset( $cbdb_settings['cbdb_pagination_prev_text'] ) && ! empty( $cbdb_settings['cbdb_pagination_prev_text'] ) ) {
								$cbdb_paginate_links['prev_text'] = $cbdb_settings['cbdb_pagination_prev_text'];
							}
							if ( isset( $cbdb_settings['cbdb_pagination_next_text'] ) && ! empty( $cbdb_settings['cbdb_pagination_next_text'] ) ) {
								$cbdb_paginate_links['next_text'] = $cbdb_settings['cbdb_pagination_next_text'];
							}
							echo wp_kses_post( paginate_links( $cbdb_paginate_links ) );
							?>
						</nav>
					</div>
					<?php
				}

				// Custom CSS.
				if ( ! empty( $cbdb_custom_css ) ) {
					?>
					<script>
						document.getElementsByTagName('head')[0].insertAdjacentHTML('beforeend', '<style type="text/css"><?php echo esc_attr( $cbdb_custom_css ); ?></style>');
					</script>
				<?php } ?>
			</section>
			<?php
		} else {
			// Else no posts found.
			echo '<p>' . esc_html__( 'Sorry, no posts found.', 'creative-blog' ) . '</p>';
		}
	} else {
		// Else no layout found.
		echo '<p>' . esc_html__( 'Sorry, no layouts found.', 'creative-blog' ) . '</p>';
	}
	// Return output html.
	$output_string = ob_get_contents();
	ob_end_clean();
	return $output_string;
}

// Register shortcode.
add_shortcode( 'creative_blog', 'creative_blog_handler' );
